@@ -1,4 +1,6 @@
-from django.shortcuts import render
+from django.contrib import messages
+from django.contrib.admin.views.decorators import staff_member_required
+from django.shortcuts import redirect, render
 
 from rq import Worker
 from rq.job import Job
@@ -7,6 +9,7 @@ from .queues import get_connection, get_connection_by_index, get_queue, get_queu
 from .settings import QUEUES, QUEUES_LIST
 
 
+@staff_member_required
 def stats(request):
     queues = []
     for index, config in enumerate(QUEUES_LIST):
@@ -29,6 +32,7 @@ def stats(request):
     return render(request, 'django_rq/stats.html', context_data)
 
 
+@staff_member_required
 def jobs(request, queue_index):
 
     queue = get_queue_by_index(int(queue_index))
@@ -41,8 +45,8 @@ def jobs(request, queue_index):
     return render(request, 'django_rq/jobs.html', context_data)
 
 
+@staff_member_required
 def job_detail(request, queue_index, job_id):
-    queue_index = int(queue_index)
     queue = get_queue_by_index(queue_index)
     job = Job.fetch(job_id, connection=queue.connection)
     context_data = {
@@ -51,3 +55,22 @@ def job_detail(request, queue_index, job_id):
         'queue': queue,
     }
     return render(request, 'django_rq/job_detail.html', context_data)
+
+
+@staff_member_required
+def delete_job(request, queue_index, job_id):
+    queue = get_queue_by_index(queue_index)
+    job = Job.fetch(job_id, connection=queue.connection)
+
+    if request.POST:
+        job.delete()
+        messages.info(request, 'You have successfully deleted %s' % job.id)
+        return redirect('rq_jobs', queue_index)
+
+    context_data = {
+        'queue_index': queue_index,
+        'job': job,
+        'queue': queue,
+    }
+    return render(request, 'django_rq/delete_job.html', context_data)
+
